# Hall

Probability theory using pythonic and (almost) mathematical notation.

## A simple example: Monty ~~Python~~ Hall 

`TODO`

## Contributing

Ensure you have [poetry](https://python-poetry.org/docs/#installation) installed, then

```bash
poetry install
```
